@@ -4,28 +4,27 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-
 #pragma once
 
-#include <QMainWindow>
 #include "ui_mainwindow.h"
+#include <QMainWindow>
 
 #include "core/types.h"
 #include "drive/permission.h"
 
-namespace KGAPI2 {
-  class Job;
+namespace KGAPI2
+{
+class Job;
 }
 
-
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
 
-  public:
+public:
     explicit MainWindow(QWidget *parent = nullptr);
 
-  private Q_SLOTS:
+private Q_SLOTS:
     /**
      * Retrieves tokens from Google that we will use to authenticate
      * further requests
@@ -43,7 +42,7 @@ class MainWindow : public QMainWindow
      */
     void permissionSelected();
 
-  private:
+private:
     Ui::MainWindow ui;
 
     KGAPI2::AccountPtr m_account;
@@ -52,4 +51,3 @@ class MainWindow : public QMainWindow
     static QString typeToName(KGAPI2::Drive::Permission::Type type);
     static QString permissionTypeToName(KGAPI2::Drive::Permission::PermissionDetails::PermissionType permissionType);
 };
-
